@@ -163,7 +163,7 @@ class RpcChain:
             return self.stub.get_unconfirmed_txs(req)
         else:
             return self.stub.get_unconfirmed_txs(
-                protos.RequestGetUnconfirmedTxs(limit=limit),
+                    protos.RequestGetUnconfirmedTxs(limit=limit),
             )
 
     def get_chain_info(self, req=None):
@@ -216,7 +216,7 @@ class RpcChain:
             return self.stub.get_validators_info(req)
         else:
             return self.stub.get_validators_info(
-                protos.RequestGetValidatorsInfo(),
+                    protos.RequestGetValidatorsInfo(),
             )
 
     def get_config(self, req=None):
@@ -235,17 +235,17 @@ class RpcChain:
             return self.stub.get_config(req)
         else:
             return self.stub.get_config(
-                protos.RequestGetConfig(),
+                    protos.RequestGetConfig(),
             )
 
-    def multisig(self, tx=None, wallet=None, token='', req=None):
+    def multisig(self, tx=None, wallet=None, token='', data=None, req=None):
 
         if req is not None:
             return self.stub.multisig(req)
         else:
-            return self.stub.multisig(
-                protos.RequestMultisig(tx=tx, wallet=wallet, token=token),
-            )
+            req = protos.RequestMultisig(tx=tx, wallet=wallet, token=token,
+                                           data=data)
+            return self.stub.multisig(req)
 
     def get_asset_address(
             self, sender_address='', itx=None,
@@ -255,8 +255,8 @@ class RpcChain:
             return self.stub.get_asset_address(req)
         else:
             return self.stub.get_asset_address(
-                protos.RequestGetAssetAddress(
-                    sender_address=sender_address, itx=itx,
-                    wallet_type=wallet_type,
-                ),
+                    protos.RequestGetAssetAddress(
+                            sender_address=sender_address, itx=itx,
+                            wallet_type=wallet_type,
+                    ),
             )
